/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser.failure.message.generator;

import com.liferay.jenkins.results.parser.Build;
import com.liferay.jenkins.results.parser.Dom4JUtil;

import org.dom4j.Element;

/**
 * @author Peter Yoo
 * @author Michael Hashimoto
 * @author Yi-Chen Tsai
 */
public class SemanticVersioningFailureMessageGenerator
	extends BaseFailureMessageGenerator {

	@Override
	public Element getMessageElement(Build build) {
		String consoleText = build.getConsoleText();

		if (!consoleText.contains(_TOKEN_SEMVER_INCORRECT) ||
			!consoleText.contains(_TOKEN_SEMVER_PACKAGE)) {

			return null;
		}

		int end = consoleText.indexOf(_TOKEN_SEMVER_INCORRECT);

		end = consoleText.indexOf("\n", end);

		int start = consoleText.lastIndexOf(_TOKEN_BASELINE_CHECK, end);

		start = consoleText.indexOf(_TOKEN_SEMVER_PACKAGE, start);

		start = consoleText.lastIndexOf("\n", start);

		return Dom4JUtil.getNewElement(
			"div", null,
			Dom4JUtil.getNewElement(
				"p", null, "Please fix ",
				Dom4JUtil.getNewElement("strong", null, "semantic versioning"),
				" on ",
				Dom4JUtil.getNewElement(
					"strong", null,
					getBaseBranchAnchorElement(build.getTopLevelBuild())),
				getConsoleTextSnippetElement(consoleText, true, start, end)));
	}

	private static final String _TOKEN_BASELINE_CHECK =
		"Checking for baseline log files";

	private static final String _TOKEN_SEMVER_INCORRECT =
		"Semantic versioning is incorrect";

	private static final String _TOKEN_SEMVER_PACKAGE = "PACKAGE_NAME";

}