/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser.test.clazz.group;

import com.liferay.jenkins.results.parser.Job;
import com.liferay.jenkins.results.parser.PortalTestClassJob;

/**
 * @author Michael Hashimoto
 */
public class TestClassGroupFactory {

	public static BatchTestClassGroup newBatchTestClassGroup(
		String batchName, Job job) {

		if (job instanceof PortalTestClassJob) {
			PortalTestClassJob portalTestClassJob = (PortalTestClassJob)job;

			if (batchName.contains("functional-")) {
				return new FunctionalBatchTestClassGroup(
					batchName, portalTestClassJob);
			}

			if (batchName.startsWith("integration-") ||
				batchName.startsWith("unit-")) {

				return new JUnitBatchTestClassGroup(
					batchName, portalTestClassJob);
			}

			if (batchName.startsWith("modules-compile-")) {
				return new ModulesCompileBatchTestClassGroup(
					batchName, portalTestClassJob);
			}

			if (batchName.startsWith("modules-integration-") ||
				batchName.startsWith("modules-unit-")) {

				return new ModulesJUnitBatchTestClassGroup(
					batchName, portalTestClassJob);
			}

			if (batchName.startsWith("modules-semantic-versioning-")) {
				return new ModulesSemVerBatchTestClassGroup(
					batchName, portalTestClassJob);
			}

			if (batchName.startsWith("plugins-compile-")) {
				return new PluginsBatchTestClassGroup(
					batchName, portalTestClassJob);
			}

			if (batchName.startsWith("portal-frontend-js-")) {
				return new NPMTestBatchTestClassGroup(
					batchName, portalTestClassJob);
			}

			if (batchName.startsWith("tck-")) {
				return new TCKJunitBatchTestClassGroup(
					batchName, portalTestClassJob);
			}

			return new DefaultBatchTestClassGroup(
				batchName, portalTestClassJob);
		}

		throw new IllegalArgumentException("Unknown test class group");
	}

}